@@ -1,12 +1,12 @@
 package WebService::Client;
 use Moo::Role;
 
-our $VERSION = '0.0501'; # VERSION
+our $VERSION = '0.0502'; # VERSION
 
 use Carp qw(croak);
 use HTTP::Request;
 use HTTP::Request::Common qw(DELETE GET POST PUT);
-use JSON qw(decode_json encode_json);
+use JSON::MaybeXS qw(decode_json encode_json);
 use LWP::UserAgent;
 
 has base_url => ( is => 'ro', required => 1 );
@@ -19,7 +19,15 @@ has ua => (
 
 has timeout => ( is => 'ro', default => 10 );
 
-has retries => ( is => 'ro', default => 0 );
+has retries => (
+    is      => 'ro',
+    default => 0,
+    isa     => sub {
+        my $r = shift;
+        die "retries must be a nonnegative integer"
+            unless defined $r and $r =~ /^\d+$/;
+    },
+);
 
 has logger => ( is => 'ro' );
 
@@ -211,7 +219,7 @@ WebService::Client - A base role for quickly and easily creating web service cli
 
 =head1 VERSION
 
-version 0.0501
+version 0.0502
 
 =head1 SYNOPSIS
 
@@ -452,6 +460,20 @@ L<Role::REST::Client>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=over
+
+=item *
+
+Dean Hamstead <L<https://github.com/djzort>>
+
+=item *
+
+Todd Wade <L<https://github.com/trwww>>
+
+=back
+
 =head1 AUTHOR
 
 Naveed Massjouni <naveed@vt.edu>
